# coding: utf-8

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ClusterHostRequirements(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'host_id': 'str',
        'total': 'ClusterHostRequirementsDetails',
        'ocp': 'ClusterHostRequirementsDetails',
        'operators': 'list[OperatorHostRequirements]'
    }

    attribute_map = {
        'host_id': 'host_id',
        'total': 'total',
        'ocp': 'ocp',
        'operators': 'operators'
    }

    def __init__(self, host_id=None, total=None, ocp=None, operators=None):  # noqa: E501
        """ClusterHostRequirements - a model defined in Swagger"""  # noqa: E501

        self._host_id = None
        self._total = None
        self._ocp = None
        self._operators = None
        self.discriminator = None

        if host_id is not None:
            self.host_id = host_id
        if total is not None:
            self.total = total
        if ocp is not None:
            self.ocp = ocp
        if operators is not None:
            self.operators = operators

    @property
    def host_id(self):
        """Gets the host_id of this ClusterHostRequirements.  # noqa: E501

        Unique identifier of the host the requirements relate to.  # noqa: E501

        :return: The host_id of this ClusterHostRequirements.  # noqa: E501
        :rtype: str
        """
        return self._host_id

    @host_id.setter
    def host_id(self, host_id):
        """Sets the host_id of this ClusterHostRequirements.

        Unique identifier of the host the requirements relate to.  # noqa: E501

        :param host_id: The host_id of this ClusterHostRequirements.  # noqa: E501
        :type: str
        """

        self._host_id = host_id

    @property
    def total(self):
        """Gets the total of this ClusterHostRequirements.  # noqa: E501

        Total host requirements for the cluster configuration  # noqa: E501

        :return: The total of this ClusterHostRequirements.  # noqa: E501
        :rtype: ClusterHostRequirementsDetails
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ClusterHostRequirements.

        Total host requirements for the cluster configuration  # noqa: E501

        :param total: The total of this ClusterHostRequirements.  # noqa: E501
        :type: ClusterHostRequirementsDetails
        """

        self._total = total

    @property
    def ocp(self):
        """Gets the ocp of this ClusterHostRequirements.  # noqa: E501

        Host requirements for the OCP installation  # noqa: E501

        :return: The ocp of this ClusterHostRequirements.  # noqa: E501
        :rtype: ClusterHostRequirementsDetails
        """
        return self._ocp

    @ocp.setter
    def ocp(self, ocp):
        """Sets the ocp of this ClusterHostRequirements.

        Host requirements for the OCP installation  # noqa: E501

        :param ocp: The ocp of this ClusterHostRequirements.  # noqa: E501
        :type: ClusterHostRequirementsDetails
        """

        self._ocp = ocp

    @property
    def operators(self):
        """Gets the operators of this ClusterHostRequirements.  # noqa: E501

        Host requirements related to requested operators  # noqa: E501

        :return: The operators of this ClusterHostRequirements.  # noqa: E501
        :rtype: list[OperatorHostRequirements]
        """
        return self._operators

    @operators.setter
    def operators(self, operators):
        """Sets the operators of this ClusterHostRequirements.

        Host requirements related to requested operators  # noqa: E501

        :param operators: The operators of this ClusterHostRequirements.  # noqa: E501
        :type: list[OperatorHostRequirements]
        """

        self._operators = operators

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ClusterHostRequirements, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClusterHostRequirements):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
